;; Generated package description from urgrep.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "urgrep" "0.6.0snapshot0.20250709.114307" "Universal recursive grep" '((emacs "28.1") (compat "29.1.0.1") (project "0.3.0")) :commit "4dd2a9a60196aa17640593659ee8aa550a9bf2e0" :keywords '("grep" "search") :url "https://github.com/jimporter/urgrep")
